@@ -197,6 +197,13 @@ limma_correction <- function(se, assay_to_normalize, batch, covar,
             batch = batch
             #design = model.matrix(~)
         )
+    }else if (length(covar) == 1) {
+        cov <- as.numeric(colData(se)[[covar]])
+        limma_corrected <- limma::removeBatchEffect(
+            assays(se)[[assay_to_normalize]],
+            batch = batch,
+            covariates = cov
+        )
     }else {
         cov <- data.frame(colData(se))[, covar]
 
@@ -329,4 +336,4 @@ svaseq_correction <- function(se, assay_to_normalize, var_of_interest,
     svaseq_assay <- dat - sv_effects
     assays(se)[[output_assay_name]] <- svaseq_assay
     return(se)
-}
\ No newline at end of file
+}
